@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.14';
+$VERSION = '5.15';
 
 =head1 NAME
 
@@ -55,6 +55,9 @@ use Labyrinth::Globals;
 use Labyrinth::DBUtils;
 use Labyrinth::Variables;
 
+use JSON::XS;
+use WWW::Mechanize;
+
 # -------------------------------------
 # The Subs
 
@@ -74,6 +77,11 @@ the classification. Return codes are:
 =cut
 
 sub CheckIP {
+    if($settings{blockurl}) {
+        my $res = _request($settings{blockurl},'check',$settings{ipaddr});
+        return $res && $res->{success} ? $res->{result} : 0;
+    }
+
     my @rows = $dbi->GetQuery('hash','FindIPAddress',$settings{ipaddr});
     return @rows ? $rows[0]->{type} : 0;
 }
@@ -89,6 +97,11 @@ sub BlockIP {
     my $who     = shift || '';
     my $ipaddr  = shift || return;
 
+    if($settings{blockurl}) {
+        my $res = _request($settings{blockurl},'block',$ipaddr,$who);
+        return $res && $res->{success} ? $res->{result} : 0;
+    }
+
     if(my @rows = $dbi->GetQuery('array','FindIPAddress',$ipaddr)) {
         $dbi->DoQuery('SaveIPAddress',$who,1,$ipaddr);
     } else {
@@ -106,6 +119,11 @@ sub AllowIP {
     my $who     = shift || '';
     my $ipaddr  = shift || return;
 
+    if($settings{blockurl}) {
+        my $res = _request($settings{blockurl},'allow',$ipaddr,$who);
+        return $res && $res->{success} ? $res->{result} : 0;
+    }
+
     if(my @rows = $dbi->GetQuery('array','FindIPAddress',$ipaddr)) {
         $dbi->DoQuery('SaveIPAddress',$who,2,$ipaddr);
     } else {
@@ -113,6 +131,20 @@ sub AllowIP {
     }
 }
 
+sub _request {
+    my $url = join('/',@_);
+
+    my $mech = WWW::Mechanize->new();
+    $mech->get($url);
+    if($mech->success()) {
+        my $json = $mech->content();
+        my $data = decode_json($json);
+        return $data;
+    }
+
+    return;
+}
+
 1;
 
 __END__
