@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.14';
+$VERSION = '5.15';
 
 =head1 NAME
 
@@ -132,8 +132,8 @@ sub init {
     my $enc      = qr{%[a-fA-F\d]{2}};
     my $legal1   = qr{[a-zA-Z\d\$\-_.+!*\'(),~\#]};
     my $legal2   = qr{[\/;:@&=]};
-    my $legal3   = qr{(?:(?:(?:$legal1|$enc)|$legal2))};
-    my $path     = qr{\/$legal3(?:\/(?:$legal3)+)*};
+    my $legal3   = qr{(?:(?:$legal1|$enc|$legal2)+)};
+    my $path     = qr{\/$legal3};
     my $query    = qr{(?:\?$legal3)+};
     my $local    = qr{[-\w\'=.]+};
 
